Choose or (temporarily) use the CRANT autosegmentation
Arguments
- set
Whether or not to permanently set the CRANT auto-segmentation as the default for
fafbsegfunctions.- expr
An expression to evaluate while CRANT is the default autosegmentation
Value
If set=TRUE a list containing the previous values of the
relevant global options (in the style of options. If
set=FALSE a named list containing the option values.
Details
bancr inherits a significant amount of infrastructure from
the fafbseg package. This has the concept of the
active autosegmentation, which in turn defines one or more R options
containing URLs pointing to voxel-wise segmentation, mesh etc data. These
are normally contained within a single neuroglancer URL which points to
multiple data layers. For banc this is the neuroglancer scene returned by
crant_scene.
Examples
if (FALSE) { # \dontrun{
choose_crant()
options()[grep("^fafbseg.*url", names(options()))]
} # }
if (FALSE) { # \dontrun{
with_crant(fafbseg::flywire_islatest('576460752653449509'))
} # }
if (FALSE) { # \dontrun{
with_crant(fafbseg::flywire_latestid('576460752653449509'))
} # }